@@ -18,6 +18,14 @@
 #include <poll.h>
 #endif
 
+#ifdef HAVE_STRING_H
+#  include <string.h>	/* Needed on NetBSD1.1/SPARC due to bzero/FD_ZERO. */
+#endif
+
+#ifdef HAVE_STRINGS_H
+#  include <strings.h>  /* Needed on AIX 4.2 due to bzero/FD_ZERO. */
+#endif
+
 static int use_count = 0;
 static oop_source_sys *sys;
 static oop_adapter_select *sel;
