@@ -114,6 +114,7 @@ oop_read *oop_rd_new(oop_source *oop, oop_readable *ra, char *buf, size_t bufsz)
   rd->allocbuf= 0;
   rd->used= 0;
   rd->alloc= buf ? bufsz : 0;
+  rd->discard= 0;
   rd->neednotcheck= 0;
   rd->displacedchar= -1;
   rd->style= *OOP_RD_STYLE_IMMED;
@@ -235,7 +236,11 @@ static void *on_process(oop_source *oop, oop_read *rd, int try_read) {
   
   if (rd->discard) {
     rd->used -= rd->discard;
-    rd->neednotcheck -= rd->discard;
+    if (rd->neednotcheck > rd->discard) {
+      rd->neednotcheck -= rd->discard;
+    } else {
+      rd->neednotcheck= 0;
+    }
     memmove(buf, buf + rd->discard, rd->used);
     rd->discard= 0;
   }
