@@ -179,8 +179,7 @@ static void *stop_readline(oop_source *src,int sig,void *data) {
 
 static void add_readline(oop_source *src) {
 	rl_callback_handler_install(
-		(char *) "> ", /* readline isn't const-correct */
-		(VFunction *) on_readline);
+		"> ", (rl_vcpfunc_t *) on_readline);
 	oop_readline_register(src);
 	src->on_signal(src,SIGQUIT,stop_readline,NULL);
 }
